@@ -5,7 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (C) 2011-2012 Star2Billing S.L.
+# Copyright (C) 2011-2014 Star2Billing S.L.
 #
 # The Initial Developer of the Original Code is
 # Arezqui Belaid <info@star2billing.com>
@@ -26,14 +26,11 @@ class AudioFile(Model):
     this allow to upload audio file and configure
     alternate Text2Speech System
     """
-    name = models.CharField(max_length=150, blank=False,
-                            verbose_name=_("audio name"),
+    name = models.CharField(max_length=150, blank=False, verbose_name=_("audio name"),
                             help_text=_('audio file label'))
-    audio_file = AudioField(upload_to='upload/audiofiles', blank=True,
-                            ext_whitelist=(".mp3", ".wav", ".ogg"),
+    audio_file = AudioField(upload_to='upload/audiofiles', blank=True, ext_whitelist=(".mp3", ".wav", ".ogg"),
                             verbose_name=_("audio file"))
-    user = models.ForeignKey(User, verbose_name=_('user'),
-                             help_text=_("select user"))
+    user = models.ForeignKey(User, verbose_name=_('user'), help_text=_("select user"))
     created_date = models.DateTimeField(auto_now_add=True)
     updated_date = models.DateTimeField(auto_now=True)
 
@@ -55,8 +52,8 @@ class AudioFile(Model):
         """audio player tag for admin"""
         if self.audio_file:
             file_url = settings.MEDIA_URL + str(self.audio_file)
-            player_string = '<ul class="playlist"><li style="width:250px;">\
-            <a href="%s">%s</a></li></ul>' % (file_url, os.path.basename(file_url))
+            player_string = '<ul class="playlist"><li style="width:250px;"><a href="%s">%s</a></li></ul>' % \
+                (file_url, os.path.basename(file_url))
             return player_string
 
     audio_file_player.allow_tags = True
